# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from __future__ import absolute_import, division, print_function

__all__ = [
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
]

__title__ = "flake8-import-order"
__summary__ = (
    "Flake8 and pylama plugin that checks the ordering of import statements."
)
__uri__ = "https://github.com/public/flake8-import-order"

__version__ = "0.2"

__author__ = "Alex Stapleton"
__email__ = "alexs@prol.etari.at"

__license__ = "LGPLv3"
__copyright__ = "Copyright 2013-2014 %s" % __author__
